@@ -22,17 +22,8 @@
 #ifndef _ARCH_PARISC_H
 #define _ARCH_PARISC_H
 
-#include <inttypes.h>
-
 #include "arch.h"
-#include "system.h"
 
-extern const struct arch_def arch_def_parisc;
-extern const struct arch_def arch_def_parisc64;
-
-int parisc_syscall_resolve_name(const char *name);
-const char *parisc_syscall_resolve_num(int num);
-
-const struct arch_syscall_def *parisc_syscall_iterate(unsigned int spot);
+ARCH_DECL(parisc)
 
 #endif
