@@ -28,7 +28,15 @@ struct util_options {
 
 int util_getopt(int argc, char *argv[], struct util_options *opts);
 
+int util_gcov_rules(const scmp_filter_ctx ctx, int action);
+
 int util_filter_output(const struct util_options *opts,
 		       const scmp_filter_ctx ctx);
 
+int util_trap_install(void);
+
+int util_action_parse(const char *action);
+
+int util_file_write(const char *path);
+
 #endif
